@@ -2,7 +2,8 @@ import math
 
 def sqrt(x):
 	if type(x) == int:
-		return math.sqrt(x)
+		print(math.sqrt(x))
 	if type(x) == float:
-		y = round(x)
-		return y
+		y = math.sqrt(x)
+		z = round(y)
+		print(z)
\ No newline at end of file
